@@ -101,8 +101,8 @@ sub drop_table
     eval {
         local $dbh->{PrintError} = 0;
         local $dbh->{PrintWarn} = 0;
-        $dbh->do(qq/drop table $table/);
-        $dbh->do(qq/drop table $table2/);
+        $dbh->do(qq/DROP TABLE $table PURGE/);
+        $dbh->do(qq/DROP TABLE $table2 PURGE/);
     };
     note("Table dropped");
 }
@@ -476,7 +476,7 @@ sub update
     # NOTE, this also checks you can pass a scalar to bind_param_array
     $sth->bind_param_array(1, 'dave');
     my @pe1 = @p1;
-    $pe1[-1] = 10;              # non-existant row
+    $pe1[-1] = 10;              # non-existent row
     $sth->bind_param_array(2, \@pe1);
     $self->insert($dbh, $sth,
                   {commit => 0, error => 0, sts => 5, affected => 4,
